==> lucene-9.12.1-src.tgz: lucene-9.12.1/lucene/suggest/src/java/org/apache/lucene/search/suggest/document/Completion99PostingsFormat.java <==
/*
 * Licensed to the Apache Software Foundation (ASF) under one or more
 * contributor license agreements.  See the NOTICE file distributed with
 * this work for additional information regarding copyright ownership.
 * The ASF licenses this file to You under the Apache License, Version 2.0
 * (the "License"); you may not use this file except in compliance with
 * the License.  You may obtain a copy of the License at
 *
 *     http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */
package org.apache.lucene.search.suggest.document;

import org.apache.lucene.codecs.PostingsFormat;

/**
 * {@link org.apache.lucene.search.suggest.document.CompletionPostingsFormat} for {@code
 * org.apache.lucene.backward_codecs.lucene99.Lucene99PostingsFormat}. This format is only used for
 * backward-compatibility of the index format and cannot be used to write data, use {@link
 * Completion912PostingsFormat} on new indices.
 *
 * @lucene.experimental
 */
public class Completion99PostingsFormat extends CompletionPostingsFormat {
  /** Creates a {@link Completion99PostingsFormat} that will load the completion FST on-heap. */
  public Completion99PostingsFormat() {
    this(FSTLoadMode.ON_HEAP);
  }

  /**
   * Creates a {@link Completion99PostingsFormat} that will use the provided <code>fstLoadMode
   * </code> to determine if the completion FST should be loaded on or off heap.
   */
  public Completion99PostingsFormat(FSTLoadMode fstLoadMode) {
    super("Completion99", fstLoadMode);
  }

  @Override
  protected PostingsFormat delegatePostingsFormat() {
    return PostingsFormat.forName("Lucene99");
  }
}

==> lucene-10.2.0-src.tgz: lucene-10.2.0/lucene/suggest/src/java/org/apache/lucene/search/suggest/document/Completion99PostingsFormat.java <==
/*
 * Licensed to the Apache Software Foundation (ASF) under one or more
 * contributor license agreements.  See the NOTICE file distributed with
 * this work for additional information regarding copyright ownership.
 * The ASF licenses this file to You under the Apache License, Version 2.0
 * (the "License"); you may not use this file except in compliance with
 * the License.  You may obtain a copy of the License at
 *
 *     http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */
package org.apache.lucene.search.suggest.document;

import org.apache.lucene.codecs.PostingsFormat;

/**
 * {@link org.apache.lucene.search.suggest.document.CompletionPostingsFormat} for {@code
 * org.apache.lucene.backward_codecs.lucene99.Lucene99PostingsFormat}. This format is only used for
 * backward-compatibility of the index format and cannot be used to write data, use {@link
 * Completion912PostingsFormat} on new indices.
 *
 * @lucene.experimental
 */
public class Completion99PostingsFormat extends CompletionPostingsFormat {
  /** Creates a {@link Completion99PostingsFormat}. */
  public Completion99PostingsFormat() {
    super("Completion99");
  }

  @Override
  protected PostingsFormat delegatePostingsFormat() {
    return PostingsFormat.forName("Lucene99");
  }
}
